﻿$URL = "PATH"
$ErrorActionPreference ="Stop"
$PSDefaultParameterValues['*:ErrorAction']='Stop'

#First time tasks
#Install-Module SharePointPnPPowerShellOnline 
#$Creds = get-credential
#Add-PnPStoredCredential -Name $URL -Username $Creds.UserName -Password $Creds.Password

import-Module SharePointPnPPowerShellOnline 
Connect-PnPOnline $URL 

function Create-MyApp([string] $ListName, [string] $ListURL,[Microsoft.SharePoint.Client.ListTemplateType] $AppType){
    #Always versioning on
    if($ListURL -eq ""){
        $ListURL =$ListName.Replace(" ","").ToLower()
    }
    New-PnPList -Title $ListName -Template $AppType -EnableVersioning -OnQuickLaunch -Url $ListURL
    Write-Host ($AppType.ToString() + " " + $ListName + " has been created!") -ForegroundColor Green    
}

$Departments = "Sales","Production", "Support"

foreach($Dep in $Departments){
    #Create the subsite
    New-PnPWeb -Title $Dep -Url $Dep -InheritNavigation -Template SITEPAGEPUBLISHING#0

    #Add navigation node to the top site
    Add-PnPNavigationNode -Location QuickLaunch -Title $Dep -Url ($URL + "/" + $Dep)
}

function Add-Apps(){
    #Add apps
    Create-MyApp -ListName "Photos" -AppType PictureLibrary
    Create-MyApp -ListName "Tasks" -AppType Tasks
}

function Add-SubsiteNavigation(){
    foreach($DepSub in $Departments){
        if($Dep -ne $DepSub){
            Add-PnPNavigationNode -Location QuickLaunch -Title $DepSub -Url ($URL + "/" + $DepSub)
        }
    }
    Add-PnPNavigationNode -Location QuickLaunch -Title "HQ" -Url $URL
    Add-PnPNavigationNode -Location QuickLaunch -Title "Pedalling" -Url "https://pedalling.com" -External

}

function Add-Pages(){
    Add-PnPClientSidePage -Name "Progress"
    Add-PnPClientSidePage -Name "Problems"
    Add-PnPClientSidePage -Name "Plans"
}

foreach($Dep in $Departments){
    $CurrWebURL =($URL + "/" + $Dep)
    #Connect to the department site
    Connect-PnPOnline $CurrWebURL 
    Add-Apps
    Add-SubsiteNavigation
    Add-Pages
}

#Connect back to the root site
Connect-PnPOnline $URL 
Add-PnPNavigationNode -Location QuickLaunch -Title "Pedalling" -Url "https://pedalling.com" -External

function Remove-All{
    foreach($Dep in $Departments){
        Remove-PnPWeb -Url $Dep -Force
    }

    $AllNodes = Get-PnPNavigationNode -Location QuickLaunch
    foreach($Node in $AllNodes){
        #$Node = $AllNodes[0]
        if($Node.Title -eq "Pedalling"){
            Remove-PnPNavigationNode  -Identity $Node.Id -Force
        }
    }
}



